import { ServerConnection } from "@jupyterlab/services";
export interface IFSResourceSpec {
    name: string;
    desc: string;
    url: string;
}
export interface IFSResource extends IFSResourceSpec {
    drive: string;
}
export interface IFSComm {
    /**
     * Send a parameterized GET request to the `/jupyterfs/resources` api, and
     * return the result.
     */
    getResourcesRequest: () => Promise<IFSResource[]>;
    /**
     * Send a parameterized POST request to the `/jupyterfs/resources` api, and
     * return the result.
     */
    initResourceRequest: (...spec: IFSResourceSpec[]) => Promise<IFSResource[]>;
    /**
     * The base url to prefix onto the uri of this Comm's requests
     */
    baseUrl: string;
}
declare abstract class FSCommBase implements IFSComm {
    constructor(props?: {
        baseUrl?: string;
    });
    abstract getResourcesRequest(): Promise<IFSResource[]>;
    abstract initResourceRequest(...spec: IFSResourceSpec[]): Promise<IFSResource[]>;
    get baseUrl(): string;
    set baseUrl(baseUrl: string);
    get resourcesUrl(): string;
    get settings(): ServerConnection.ISettings;
    protected _settings: ServerConnection.ISettings | undefined;
}
export declare class FSComm extends FSCommBase {
    getResourcesRequest(): Promise<IFSResource[]>;
    initResourceRequest(...spec: IFSResourceSpec[]): Promise<IFSResource[]>;
}
export {};
